package com.op.mes.service;

import com.op.mes.domain.ProRecipe;

import java.util.List;

/**
 * 配药配方Service接口
 *
 * @author yinjinlu
 * @date 2022-05-11
 */
public interface IProRecipeService
{
    /**
     * 查询配药配方
     *
     * @param processId 配药配方主键
     * @return 配药配方
     */
    public ProRecipe selectProRecipeByRecipeId(String processId);

    /**
     * 查询配药配方列表
     *
     * @param proRecipe 配药配方
     * @return 配药配方集合
     */
    public List<ProRecipe> selectProRecipeList(ProRecipe proRecipe);

    public Boolean checkRecipeCodeUnique(ProRecipe proRecipe);
    public Boolean checkRecipeNameUnique(ProRecipe proRecipe);

    /**
     * 新增配药配方
     *
     * @param proRecipe 配药配方
     * @return 结果
     */
    public int insertProRecipe(ProRecipe proRecipe);

    /**
     * 修改配药配方
     *
     * @param proRecipe 配药配方
     * @return 结果
     */
    public int updateProRecipe(ProRecipe proRecipe);

    /**
     * 批量删除配药配方
     *
     * @param processIds 需要删除的配药配方主键集合
     * @return 结果
     */
    public int deleteProRecipeByRecipeIds(String[] processIds);

    /**
     * 删除配药配方信息
     *
     * @param processId 配药配方主键
     * @return 结果
     */
    public int deleteProRecipeByRecipeId(String processId);
}
